==> sms-db-service-1.0-20171113.071444-6.jar: sqlite/schema/data.sql <==
INSERT INTO sms_sp_info (sp_id, sp_name, sp_class, sp_class_name, sms_type, support_carriers, account, password,
api_url,ext1,ext2, ext3, ext_json)
VALUES
  ('mock_verify', '测试验证码', 'mock', 'mock', 'VERIFY_CODE', 'MOBILE,UNICOM,TELECOM', '', '', '', '', '', '', ''),
  ('mock_notify', '测试通知短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', '', '', '', '', '', '', ''),
  ('mock_sale', '测试营销短信', 'mock', 'mock', 'SALE_MESSAGE', 'MOBILE,UNICOM,TELECOM', '', '', '', '', '', '', ''),
  ('mock_mobile', '测试移动短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'MOBILE', '', '', '', '', '', '', ''),
  ('mock_unicom', '测试联通短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'UNICOM', '', '', '', '', '', '', ''),
  ('mock_telecom', '测试电信短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'TELECOM', '', '', '', '', '', '', ''),
  ('mongate_reg', '梦网注册', 'mongate', 'mongate', 'NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', 'JS2189', '120272',
                  '61.145.229.26:8086', '', '', '', ''),
  ('guodu_sale', '国都营销', 'guodu', 'guodu',' NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', 'xunlyx',
                 'xunlyx', 'http://124.251.7.68:8000/HttpQuickProcess/submitMessageAll', '', '', '', ''),
  ('arc_soft_sale', '优易付营销', 'arcsoft', 'arcsoft', 'NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', '2000070',
                    '18063ea045cd7a1ad869c872f96ed70d', 'http://fee.arc-soft.com:23000/sdkfee/sms/mt',
                    '3defc0e829cd11e5827bc6a10b512583', '', '', '');
;

INSERT INTO sms_queue (queue_id, queue_name, sp_id, priority)
VALUES
  ('mock', '测试', 'mock_verify', 1),
  ('mock', '测试', 'mock_sale', 2),
  ('mock', '测试', 'mock_notify', 3),
  ('mock_carriers', '测试', 'mock_mobile', 1),
  ('mock_carriers', '测试', 'mock_unicom', 2),
  ('mock_carriers', '测试', 'mock_telecom', 3)
;

INSERT INTO sms_biz_info (biz_no, biz_name, biz_key, queue_id)
VALUES
  ('00000', '测试', '111', 'mock'),
  ('000000', '测试运营商', '111', 'mock_carriers'),
  ('000001', '渠道后台', '111', 'mock_carriers')
;

INSERT INTO sms_biz_ip_info(biz_no, ip_config, ip_describe)
VALUES
  -- 00000
  ('00000', '127.0.0.0/16', '本地ip'),
  ('00000', '10.10.0.0/16', '局域网ip'),
  ('00000', '192.168.0.0/16', '局域网ip'),
  ('00000', '10.33.0.0/16', 'tw06的局域网ip'),
  ('00000', '61.155.0.0/16', 'tw06的ip'),
  ('00000', '153.37.0.0/16', 'tw06的ip'),
  ('00000', '14.152.0.0/16', '公司外网ip'),
  -- 000000
  ('000000', '127.0.0.0/16', '本地ip'),
  ('000000', '10.10.0.0/16', '局域网ip'),
  ('000000', '192.168.0.0/16', '局域网ip'),
  ('000000', '10.33.0.0/16', 'tw06的局域网ip'),
  ('000000', '61.155.0.0/16', 'tw06的ip'),
  ('000000', '153.37.0.0/16', 'tw06的ip'),
  ('000000', '14.152.0.0/16', '公司外网ip'),
  -- 000001
  ('000001', '127.0.0.0/16', '本地ip'),
  ('000001', '10.10.0.0/16', '局域网ip'),
  ('000001', '192.168.0.0/16', '局域网ip'),
  ('000001', '10.33.0.0/16', 'tw06的局域网ip'),
  ('000001', '61.155.0.0/16', 'tw06的ip'),
  ('000001', '153.37.0.0/16', 'tw06的ip'),
  ('000001', '14.152.0.0/16', '公司外网ip')
;

INSERT INTO config_info (config_group, config_name, config_value, config_describe)
VALUES
  ('mobile_carriers', 'mobile_statement',
   '1340,1341,1342,1343,1344,1345,1346,1347,1348,135,136,137,138,139,147,150,151,152,157,158,159,178,182,183,184,187,
   188,1703,1704,1705,1706', '移动手机号码段'),
  ('mobile_carriers', 'unicom_statement', '130,131,132,145,155,156,175,176,185,186,1707,1708,1709,171', '联通手机号码段'),
  ('mobile_carriers', 'telecom_statement', '133,1349,149,153,173,177,180,181,189,1700,1701,1702', '电信手机号码段'),
  ('verify_code_config', 'verify_code_time_out', '30', '验证码超时时间（秒）'),
  ('manager_api_user', 'channel', 'iC6nLyMt8ygGf54XQ87Mlmphveu3xubmTlB0tqZDJAUi8ksn6DQIynG1fadXIoKR',
   'api访问用户名和密钥（configName为用户名,configValue为密码）'),
  -- risk config
  ('ip_limiter_config', 'ip_limiter_time_out', '30', '单个ip超时时间'),
  ('ip_limiter_config', 'ip_limiter_times', '2', '超时时间内允许的最大次数'),
  ('device_limiter_config', 'device_limiter_time_out', '30', '单个device超时时间'),
  ('device_limiter_config', 'device_limiter_times', '2', '超时时间内允许的最大次数'),
  ('mobile_limiter_config', 'mobile_limiter_time_out', '30', '单个mobile超时时间'),
  ('mobile_limiter_config', 'mobile_limiter_times', '4', '超时时间内允许的最大次数'),
  -- threat hunter
  ('threat_hunter_config', 'user', 'xunlei', '永安在线科技用户名'),
  ('threat_hunter_config', 'key', '9BpoVqbKvXhyass#LClFF0SJX6Cyd88e', '永安在线科技秘钥'),
  ('threat_hunter_config', 'url', 'https://api.zhanghaobao.net/zhbpro/phone_no_check', 'api url'),
  ('threat_hunter_config', 'timeout_mills', '2000', 'http timeout mills'),
  -- health
  ('health_exception_report', 'storage_time_seconds', '3600', '异常数据在缓存内保存的时间长'),
  ('health_exception_report', 'trigger_least_size', '3', '在缓存时间内，异常预警触发至少需要的次数')
;

==> sms-db-service-1.0-20171213.143042-25.jar: sqlite/schema/data.sql <==
INSERT INTO sms_sp_info (sp_id, sp_name, sp_class, sp_class_name, sms_type, support_carriers, account, password,
api_url,ext1,ext2, ext3, ext_json)
VALUES
  ('mock_verify', '测试验证码', 'mock', 'mock', 'VERIFY_CODE', 'MOBILE,UNICOM,TELECOM', '', '', '', '', '', '', ''),
  ('mock_notify', '测试通知短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', '', '', '', '', '', '', ''),
  ('mock_sale', '测试营销短信', 'mock', 'mock', 'SALE_MESSAGE', 'MOBILE,UNICOM,TELECOM', '', '', '', '', '', '', ''),
  ('mock_mobile', '测试移动短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'MOBILE', '', '', '', '', '', '', ''),
  ('mock_unicom', '测试联通短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'UNICOM', '', '', '', '', '', '', ''),
  ('mock_telecom', '测试电信短信', 'mock', 'mock', 'NOTIFY_MESSAGE', 'TELECOM', '', '', '', '', '', '', ''),
  ('mongate_reg', '梦网注册', 'mongate', 'mongate', 'NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', 'JS2189', '120272',
                  '61.145.229.26:8086', '', '', '', ''),
  ('guodu_sale', '国都营销', 'guodu', 'guodu',' NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', 'xunlyx',
                 'xunlyx', 'http://124.251.7.68:8000/HttpQuickProcess/submitMessageAll', '', '', '', ''),
  ('arc_soft_sale', '优易付营销', 'arcsoft', 'arcsoft', 'NOTIFY_MESSAGE', 'MOBILE,UNICOM,TELECOM', '2000070',
                    '18063ea045cd7a1ad869c872f96ed70d', 'http://fee.arc-soft.com:23000/sdkfee/sms/mt',
                    '3defc0e829cd11e5827bc6a10b512583', '', '', '');
;

INSERT INTO sms_queue (queue_id, queue_name, sp_id, priority)
VALUES
  ('mock', '测试', 'mock_verify', 1),
  ('mock', '测试', 'mock_sale', 2),
  ('mock', '测试', 'mock_notify', 3),
  ('mock_carriers', '测试', 'mock_mobile', 1),
  ('mock_carriers', '测试', 'mock_unicom', 2),
  ('mock_carriers', '测试', 'mock_telecom', 3)
;

INSERT INTO sms_biz_info (biz_no, biz_name, biz_group, biz_key, queue_id)
VALUES
  ('00000', '测试', ' 测试线','111', 'mock'),
  ('000000', '测试运营商',  '测试运营商线','111', 'mock_carriers'),
  ('000001', '渠道后台',  ' ','渠道后台线', 'mock_carriers')
;

INSERT INTO sms_biz_ip_info(biz_no, ip_config, ip_describe)
VALUES
  -- 00000
  ('00000', '127.0.0.0/16', '本地ip'),
  ('00000', '10.10.0.0/16', '局域网ip'),
  ('00000', '192.168.0.0/16', '局域网ip'),
  ('00000', '10.33.0.0/16', 'tw06的局域网ip'),
  ('00000', '61.155.0.0/16', 'tw06的ip'),
  ('00000', '153.37.0.0/16', 'tw06的ip'),
  ('00000', '14.152.0.0/16', '公司外网ip'),
  -- 000000
  ('000000', '127.0.0.0/16', '本地ip'),
  ('000000', '10.10.0.0/16', '局域网ip'),
  ('000000', '192.168.0.0/16', '局域网ip'),
  ('000000', '10.33.0.0/16', 'tw06的局域网ip'),
  ('000000', '61.155.0.0/16', 'tw06的ip'),
  ('000000', '153.37.0.0/16', 'tw06的ip'),
  ('000000', '14.152.0.0/16', '公司外网ip'),
  -- 000001
  ('000001', '127.0.0.0/16', '本地ip'),
  ('000001', '10.10.0.0/16', '局域网ip'),
  ('000001', '192.168.0.0/16', '局域网ip'),
  ('000001', '10.33.0.0/16', 'tw06的局域网ip'),
  ('000001', '61.155.0.0/16', 'tw06的ip'),
  ('000001', '153.37.0.0/16', 'tw06的ip'),
  ('000001', '14.152.0.0/16', '公司外网ip')
;

INSERT INTO config_info (config_group, config_name, config_value, config_describe)
VALUES
  ('mobile_carriers', 'mobile_statement',
   '1340,1341,1342,1343,1344,1345,1346,1347,1348,135,136,137,138,139,147,150,151,152,157,158,159,178,182,183,184,187,
   188,1703,1704,1705,1706', '移动手机号码段'),
  ('mobile_carriers', 'unicom_statement', '130,131,132,145,155,156,175,176,185,186,1707,1708,1709,171', '联通手机号码段'),
  ('mobile_carriers', 'telecom_statement', '133,1349,149,153,173,177,180,181,189,1700,1701,1702', '电信手机号码段'),
  ('verify_code_config', 'verify_code_time_out', '30', '验证码超时时间（秒）'),
  ('manager_api_user', 'channel', 'iC6nLyMt8ygGf54XQ87Mlmphveu3xubmTlB0tqZDJAUi8ksn6DQIynG1fadXIoKR',
   'api访问用户名和密钥（configName为用户名,configValue为密码）'),
  -- risk config
  ('ip_limiter_config', 'ip_limiter_time_out', '30', '单个ip超时时间'),
  ('ip_limiter_config', 'ip_limiter_times', '2', '超时时间内允许的最大次数'),
  ('device_limiter_config', 'device_limiter_time_out', '30', '单个device超时时间'),
  ('device_limiter_config', 'device_limiter_times', '2', '超时时间内允许的最大次数'),
  ('mobile_limiter_config', 'mobile_limiter_time_out', '30', '单个mobile超时时间'),
  ('mobile_limiter_config', 'mobile_limiter_times', '4', '超时时间内允许的最大次数'),
  -- threat hunter
  ('threat_hunter_config', 'user', 'xunlei', '永安在线科技用户名'),
  ('threat_hunter_config', 'key', '9BpoVqbKvXhyass#LClFF0SJX6Cyd88e', '永安在线科技秘钥'),
  ('threat_hunter_config', 'url', 'https://api.zhanghaobao.net/zhbpro/phone_no_check', 'api url'),
  ('threat_hunter_config', 'timeout_mills', '2000', 'http timeout mills'),
  -- health
  ('health_exception_report', 'storage_time_seconds', '3600', '异常数据在缓存内保存的时间长'),
  ('health_exception_report', 'trigger_least_size', '3', '在缓存时间内，异常预警触发至少需要的次数')
;
